﻿Imports Ivi.Visa.Interop

Module Digitize

    Sub Main()

        'This program gives an example of how you can use the 34461A to digitize a signal. It follows closely the settings found for the 34411A Digitizing video
        'found at http:'www.youtube.com/watch?v=gxLrF4sgAxk The 34461A does not offer all of the triggering options that the 34411A has so some of the features from
        'the video are not shown in this programming example.

        'For more information on getting started using VISA COM I/O operations see the app note located at:
        'http:'cp.literature.agilent.com/litweb/pdf/5989-6338EN.pdf
        Dim rm As Ivi.Visa.Interop.ResourceManager = New Ivi.Visa.Interop.ResourceManager()   'Open up a new resource manager
        Dim myDmm As Ivi.Visa.Interop.FormattedIO488 = New Ivi.Visa.Interop.FormattedIO488()  'Open a new Formatted IO 488 session 

        Try

            'Dim DutAddr as String = "GPIB0::22"  'String for GPIB
            'Dim DutAddr as String = "TCPIP0::169.254.4.61"   'Example string for LAN
            'Dim DutAddr as String = "USB0::0x0957::0x1A07::MY53000101"  'Example string for USB
            'Dim DutAddr As String = "USB0::0x0957::0x1C07::US00000069::0::INSTR"  'String for GPIB
            Dim DutAddr As String = "TCPIP0::156.140.92.16"   'Example string for LAN

            myDmm.IO = rm.Open(DutAddr, AccessMode.NO_LOCK, 2000, "")  'Open up a handle to the DMM with a 2 second timeout
            myDmm.IO.Timeout = 3000  'You can also set your timeout by doing this command, sets to 3 seconds

            'First start off with a reset state
            myDmm.IO.Clear()  'Send a device clear first to stop any measurements in process
            myDmm.WriteString("*RST")  'Reset the device
            myDmm.WriteString("*IDN?")  'Get the IDN string                
            Dim IDN As String = myDmm.ReadString()
            Console.WriteLine(IDN)  'report the DMM's identity

            'Configure the 34461 DCV Measurement state
            myDmm.WriteString("CONF:VOLT:DC 10")               'Configure DCV, 10V range
            myDmm.WriteString("VOLT:IMP:AUTO OFF")        '10M input impedance setting , "ON" sets >10Gohm
            myDmm.WriteString("SENS:VOLT:DC:ZERO:AUTO OFF")    ' Autozero Off                
            myDmm.WriteString("VOLT:NPLC .02")                'Set Integration Time Resolution to .02 PLC
            CheckDMMError(myDmm)                       'Check the DMM for errors


            'Configure trigger settings
            myDmm.WriteString("TRIG:SOUR IMM")                 'Set trigger source to internal
            myDmm.WriteString("TRIG:SLOP POS")                 'Set trigger slop to pos
            myDmm.WriteString("TRIG:COUN 1")                   'Set trigger source to internal                
            myDmm.WriteString("TRIG:DEL:AUTO OFF")             'Turn OFF Automatic trigger delay
            myDmm.WriteString("TRIG:DEL 0")                    ' Set trigger delay to 0 sec
            CheckDMMError(myDmm)                       'Check the DMM for errors

            'Configure Sample settings
            myDmm.WriteString("SAMP:COUN 10000")               'Set sample count = 10000
            CheckDMMError(myDmm)                       'Check the DMM for errors

            'Trigger and make the readings
            myDmm.IO.Timeout = 15000                              'Allow 12 seconds for DMM to make readings
            myDmm.WriteString("INIT")                            'Put DMM in wait for Trigger state

            myDmm.WriteString("FETCH?")                         'Get all the readings from Buffer

            'Now Populate the console with the readings
            Dim Readings As String = myDmm.ReadString()                  'Get the readings in a string format
            Dim rdgArr As String() = Readings.Split(",".ToCharArray())   'Split the readings into individual elements

            For Each rdg As Double In rdgArr ' Write out each result to the console
                Console.WriteLine(rdg.ToString())
            Next



        Catch e As Exception

            Console.WriteLine("Error occured: " + e.Message)

        Finally

            'Close out your resources
            Try
                myDmm.IO.Close()
            Catch ex As Exception

            End Try
            Try
                System.Runtime.InteropServices.Marshal.ReleaseComObject(myDmm)
            Catch ex As Exception

            End Try

            Try
                System.Runtime.InteropServices.Marshal.ReleaseComObject(rm)
            Catch ex As Exception

            End Try
            Console.WriteLine("Press any key to continue...")
            Console.ReadKey()

        End Try
    End Sub
    Sub CheckDMMError(myDmm As FormattedIO488)
        myDmm.WriteString("SYST:ERR?")
        Dim errStr As String = myDmm.ReadString()

        If (errStr.Contains("No error")) Then 'If no error, then return
            Return
            'If there is an error, read out all of the errors and return them in an exception
        Else
            Dim errStr2 As String = ""
            Do
                myDmm.WriteString("SYST:ERR?")
                errStr2 = myDmm.ReadString()
                If (Not errStr2.Contains("No error")) Then
                    errStr = errStr + "\n" + errStr2
                End If
            Loop While (Not errStr2.Contains("No error"))
            Throw New Exception("Exception: Encountered system error(s)\n" + errStr)

        End If

    End Sub

End Module
