﻿Imports Ivi.Visa.Interop
Module Histogram
    '' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
    ''  © Agilent Technologies, Inc. 2013
    ''
    '' You have a royalty-free right to use, modify, reproduce and distribute
    '' the Sample Application Files (and/or any modified version) in any way
    '' you find useful, provided that you agree that Agilent Technologies has no
    '' warranty,  obligations or liability for any Sample Application Files.
    ''
    '' Agilent Technologies provides programming examples for illustration only,
    '' This sample program assumes that you are familiar with the programming
    '' language being demonstrated and the tools used to create and debug
    '' procedures. Agilent Technologies support engineers can help explain the
    '' functionality of Agilent Technologies software components and associated
    '' commands, but they will not modify these samples to provide added
    '' functionality or construct procedures to meet your specific needs.
    '' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
    Sub Main()



        ' This example rogrammatically sets the display mode to histogram views. 
        ' Takes a sample of 500 readings per trigger and reports on the results while the display shows the distribution in histogram mode.
        ' Then downloads a screen capture to the PC. Screen capture illustrates IEEE block transfer method.

        'For more information on getting started using VISA COM I/O operations see the app note located at:
        'http:'cp.literature.agilent.com/litweb/pdf/5989-6338EN.pdf
        Dim rm As Ivi.Visa.Interop.ResourceManager = New Ivi.Visa.Interop.ResourceManager()   'Open up a new resource manager
        Dim myDmm As Ivi.Visa.Interop.FormattedIO488 = New Ivi.Visa.Interop.FormattedIO488()  'Open a new Formatted IO 488 session 

        Try

            'Dim DutAddr as String = "GPIB0::22"  'String for GPIB
            'Dim DutAddr as String = "TCPIP0::169.254.4.61"   'Example string for LAN
            'Dim DutAddr as String = "USB0::0x0957::0x1A07::MY53000101"  'Example string for USB
            'Dim DutAddr As String = "USB0::0x0957::0x1C07::US00000069::0::INSTR"  'String for GPIB
            Dim DutAddr As String = "TCPIP0::156.140.92.16"   'Example string for LAN

            myDmm.IO = rm.Open(DutAddr, AccessMode.NO_LOCK, 2000, "")  'Open up a handle to the DMM with a 2 second timeout
            myDmm.IO.Timeout = 3000  'You can also set your timeout by doing this command, sets to 3 seconds

            'First start off with a reset state
            myDmm.IO.Clear()  'Send a device clear first to stop any measurements in process
            myDmm.WriteString("*RST")  'Reset the device
            myDmm.WriteString("*IDN?")  'Get the IDN string                
            Dim IDN As String = myDmm.ReadString()
            Console.WriteLine(IDN)  'report the DMM's identity
            'Set the Display to Histogram mode, DCV and get 100 readings

            'Configure for DCV 100V range, 10mV resolution this is a fast reading
            myDmm.WriteString("CONF:VOLT:DC 100, 0.01")

            myDmm.WriteString("DISP:VIEW HIST")  'Set to HISTogram view, options are NUMeric|HISTogram|TCHart|METer

            myDmm.WriteString("SAMP:COUN 500")  'Get 100 Readings per trigger
            myDmm.WriteString("READ?")  'Trigger the DMM to start the readings, can also use INIT command
            Dim DCVResult As Object() = myDmm.ReadList(IEEEASCIIType.ASCIIType_Any)  ' Get the readings in an array

            For Each rdg As Double In DCVResult ' Write out each result to the console
                Console.WriteLine(rdg.ToString())
            Next
            CheckDMMError(myDmm)  'Check if the DMM has any errors

            'Here's where you can get a screen capture of the display
            myDmm.WriteString("HCOP:SDUM:DATA:FORM PNG")  'Set the format to PNG or BMP
            myDmm.WriteString("HCOP:SDUM:DATA?")  'Send the command to get the screen data
            Dim junk As Byte() = CType(myDmm.ReadIEEEBlock(IEEEBinaryType.BinaryType_UI1), Byte())  'Read the data back from DMM. DMM returns in IEEE block format
            CheckDMMError(myDmm)  'Check DMM for Errors

            Dim OutFilename As String = "C:\\Temp\\ScreenCapture.png"  'Set picture location
            Dim f As System.IO.FileStream = System.IO.File.Open(OutFilename, System.IO.FileMode.Create)  'Create/Overwrite the local copy of the file

            f.Write(junk, 0, junk.Length)  'Write the picture data
            f.Close()  'Close picture file
            Console.WriteLine("DMM Display saved at: " + OutFilename)


        Catch e As Exception

            Console.WriteLine("Error occured: " + e.Message)

        Finally

            'Close out your resources
            Try
                myDmm.IO.Close()
            Catch ex As Exception

            End Try
            Try
                System.Runtime.InteropServices.Marshal.ReleaseComObject(myDmm)
            Catch ex As Exception

            End Try

            Try
                System.Runtime.InteropServices.Marshal.ReleaseComObject(rm)
            Catch ex As Exception

            End Try
            Console.WriteLine("Press any key to continue...")
            Console.ReadKey()

        End Try
    End Sub
    Sub CheckDMMError(myDmm As FormattedIO488)
        myDmm.WriteString("SYST:ERR?")
        Dim errStr As String = myDmm.ReadString()

        If (errStr.Contains("No error")) Then 'If no error, then return
            Return
            'If there is an error, read out all of the errors and return them in an exception
        Else
            Dim errStr2 As String = ""
            Do
                myDmm.WriteString("SYST:ERR?")
                errStr2 = myDmm.ReadString()
                If (Not errStr2.Contains("No error")) Then
                    errStr = errStr + "\n" + errStr2
                End If
            Loop While (Not errStr2.Contains("No error"))
            Throw New Exception("Exception: Encountered system error(s)\n" + errStr)

        End If

    End Sub

End Module
