﻿Imports Ivi.Visa.Interop
Module MaxAccuracy
    '' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
    ''  © Agilent Technologies, Inc. 2013
    ''
    '' You have a royalty-free right to use, modify, reproduce and distribute
    '' the Sample Application Files (and/or any modified version) in any way
    '' you find useful, provided that you agree that Agilent Technologies has no
    '' warranty,  obligations or liability for any Sample Application Files.
    ''
    '' Agilent Technologies provides programming examples for illustration only,
    '' This sample program assumes that you are familiar with the programming
    '' language being demonstrated and the tools used to create and debug
    '' procedures. Agilent Technologies support engineers can help explain the
    '' functionality of Agilent Technologies software components and associated
    '' commands, but they will not modify these samples to provide added
    '' functionality or construct procedures to meet your specific needs.
    '' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
    Sub Main()

        ' This example sets the maximum accuray for DCV. It illustrates how to use NPLC or resolution settings. It takes a single reading.
        ' We also go through and take multiple readings using a single trigger. We show the relationship to Timeout parameters when taking longer readings.



        'For more information on getting started using VISA COM I/O operations see the app note located at:
        'http:'cp.literature.agilent.com/litweb/pdf/5989-6338EN.pdf
        Dim rm As Ivi.Visa.Interop.ResourceManager = New Ivi.Visa.Interop.ResourceManager()   'Open up a new resource manager
        Dim myDmm As Ivi.Visa.Interop.FormattedIO488 = New Ivi.Visa.Interop.FormattedIO488()  'Open a new Formatted IO 488 session 

        Try

            'Dim DutAddr as String = "GPIB0::22"  'String for GPIB
            'Dim DutAddr as String = "TCPIP0::169.254.4.61"   'Example string for LAN
            'Dim DutAddr as String = "USB0::0x0957::0x1A07::MY53000101"  'Example string for USB
            'Dim DutAddr As String = "USB0::0x0957::0x1C07::US00000069::0::INSTR"  'String for GPIB
            Dim DutAddr As String = "TCPIP0::156.140.92.16"   'Example string for LAN

            myDmm.IO = rm.Open(DutAddr, AccessMode.NO_LOCK, 2000, "")  'Open up a handle to the DMM with a 2 second timeout
            myDmm.IO.Timeout = 3000  'You can also set your timeout by doing this command, sets to 3 seconds

            'First start off with a reset state
            myDmm.IO.Clear()  'Send a device clear first to stop any measurements in process
            myDmm.WriteString("*RST")  'Reset the device
            myDmm.WriteString("*IDN?")  'Get the IDN string                
            Dim IDN As String = myDmm.ReadString()
            Console.WriteLine(IDN)  'report the DMM's identity
            
            'Configure for DCV 100V range, 10mV resolution this is a fast reading
            myDmm.WriteString("CONF:VOLT:DC 100, 0.01")

            'Now let's set the maximum resolution, there are two methods

            '1. Setting the NPLC to 100 will give the DMM the most time to integrate the readings going into it. NPLC = Number of power line cycles. 
            '1 NPLC = 1 power line cycle. Example 1 NPLC in US = 1/60Hz = 16.66 ms. 100NPLC = 1.6 seconds. 
            ' Using an NPLC setting has the added benefit of rejecting power line noise i.e. normal mode rejection. 
            'Setting the maximum NPLC ensures the maximum resolution without needing to calculate or lookup resolution in measurement units i.e. V, I, Ohms

            myDmm.WriteString("VOLT:DC:NPLC 100")  'Set to 100 NPLC, NPLC can be set to 0.02|0.2|1|10|100        

            '2. The other way to get maximum resolution is to set the resolution. Setting the resolution is more intuitive to directly set how many
            ' digits you want to in your readings. However, this requires a little bit of calculations. For the 34461A, max resolution = 0.3ppm. For
            ' 34460A, max resolution = 3.0ppm.                  

            myDmm.WriteString("VOLT:DC:RES .0003")  ' 34460A Max resolution on 100V range = 100*3e-6 = .0003                         
            myDmm.WriteString("VOLT:DC:RES .00003")  ' 34461A Max resolution on 100V range = 100*0.3e-6 = .00003         

            'Autozero: the instrument internally disconnects the input signal following each measurement and takes a zero measurement. 
            ' It then subtracts the zero measurement from the preceding measurement. 
            ' This prevents offset voltages present on the instrument's input circuitry from affecting measurement accuracy. 

            myDmm.WriteString("VOLT:DC:ZERO:AUTO ON")  'Turn auto zero on for each measurement. 

            myDmm.WriteString("READ?")  'Trigger the DMM to start the readings, can also use INIT and FETCH commands
            Dim rdg As Double = myDmm.ReadNumber(IEEEASCIIType.ASCIIType_Any)
            Console.WriteLine(rdg.ToString())

            CheckDMMError(myDmm)  'Check if the DMM has any errors                



        Catch e As Exception

            Console.WriteLine("Error occured: " + e.Message)

        Finally

            'Close out your resources
            Try
                myDmm.IO.Close()
            Catch ex As Exception

            End Try
            Try
                System.Runtime.InteropServices.Marshal.ReleaseComObject(myDmm)
            Catch ex As Exception

            End Try

            Try
                System.Runtime.InteropServices.Marshal.ReleaseComObject(rm)
            Catch ex As Exception

            End Try
            Console.WriteLine("Press any key to continue...")
            Console.ReadKey()

        End Try
    End Sub
    Sub CheckDMMError(myDmm As FormattedIO488)
        myDmm.WriteString("SYST:ERR?")
        Dim errStr As String = myDmm.ReadString()

        If (errStr.Contains("No error")) Then 'If no error, then return
            Return
            'If there is an error, read out all of the errors and return them in an exception
        Else
            Dim errStr2 As String = ""
            Do
                myDmm.WriteString("SYST:ERR?")
                errStr2 = myDmm.ReadString()
                If (Not errStr2.Contains("No error")) Then
                    errStr = errStr + "\n" + errStr2
                End If
            Loop While (Not errStr2.Contains("No error"))
            Throw New Exception("Exception: Encountered system error(s)\n" + errStr)

        End If

    End Sub

End Module
